==> syncart-8.x-2.37.tar.gz: syncart/src/Hook/Theme.php <==
<?php

namespace Drupal\syncart\Hook;

/**
 * ThemeHooks.
 */
class Theme {

  /**
   * Implements hook_theme().
   */
  public static function hook() {
    return [
      'syncart-cart-field' => [
        'template' => 'field/cart--field',
        'variables' => ['data' => []],
      ],
      'syncart-cart' => [
        'template' => 'layout/cart',
        'variables' => ['data' => []],
      ],
      'syncart-cart-small' => [
        'template' => 'block/cart--small',
        'variables' => ['data' => []],
      ],
      'syncart-favorite-field' => [
        'template' => 'field/favorite--field',
        'variables' => ['data' => []],
      ],
      'syncart-favorites' => [
        'template' => 'layout/favorites',
        'variables' => ['data' => []],
      ],
      'syncart-favorites' => [
        'template' => 'layout/favorites',
        'variables' => ['data' => []],
      ],
      'commerce_checkout_completion_message' => [
        'template' => 'commerce/commerce-checkout-completion-message',
        'base hook' => 'commerce_checkout_completion_message',
      ],
      'commerce_checkout_form' => [
        'template' => 'commerce/commerce-checkout-form',
        'base hook' => 'commerce_checkout_form',
      ],
      'commerce_order_receipt' => [
        'template' => 'commerce/commerce-order-receipt',
        'base hook' => 'commerce_order_receipt',
      ],
      'commerce_order__user' => [
        'template' => 'commerce/commerce-order--user',
        'base hook' => 'commerce_order__user',
      ],
      'commerce_order__admin' => [
        'template' => 'commerce/commerce-order--admin',
        'base hook' => 'commerce_order__admin',
      ],
    ];
  }

}

==> syncart-8.x-2.45.tar.gz: syncart/src/Hook/Theme.php <==
<?php

namespace Drupal\syncart\Hook;

/**
 * ThemeHooks.
 */
class Theme {

  /**
   * Implements hook_theme().
   */
  public static function hook() {
    return [
      'syncart-cart-field' => [
        'template' => 'field/cart--field',
        'variables' => ['data' => []],
      ],
      'syncart-cart' => [
        'template' => 'cart',
        'variables' => ['data' => []],
      ],
      'syncart-cart-small' => [
        'template' => 'block/cart--small',
        'variables' => ['data' => []],
      ],
      'syncart-favorite-field' => [
        'template' => 'field/favorite--field',
        'variables' => ['data' => []],
      ],
      'syncart-favorites' => [
        'template' => 'layout/favorites',
        'variables' => ['data' => []],
      ],
      'syncart-favorites' => [
        'template' => 'layout/favorites',
        'variables' => ['data' => []],
      ],
      'commerce_checkout_completion_message' => [
        'template' => 'commerce/commerce-checkout-completion-message',
        'base hook' => 'commerce_checkout_completion_message',
      ],
      'commerce_checkout_form' => [
        'template' => 'commerce/commerce-checkout-form',
        'base hook' => 'commerce_checkout_form',
      ],
      'commerce_order_receipt' => [
        'template' => 'commerce/commerce-order-receipt',
        'base hook' => 'commerce_order_receipt',
      ],
      'commerce_order__user' => [
        'template' => 'commerce/commerce-order--user',
        'base hook' => 'commerce_order__user',
      ],
      'commerce_order__admin' => [
        'template' => 'commerce/commerce-order--admin',
        'base hook' => 'commerce_order__admin',
      ],
    ];
  }

}
